;Filename: TMod.s
;Part: ADuC703x.
;Created: 12/04/2006
;Author: Eckart Hartmann of Analog Devices
;This file is in beta sampling.

;This software is supplied subject our standard software license agreement.
;A non-binding summary is as follows:
;"You may use the software in your own code at your own risk.
;" ADI inc disclaims any warranty or liability of its use".
;The full standard software license agreement is available on request and
; remains the binding agreement.

#include        "..\Fla\ADuC703xi.equ"
Z_TnLD      DEFINE  0x300
Z_TnVAL     DEFINE  0x304
Z_TnCON     DEFINE  0x308
Z_TnCLRI    DEFINE  0x30c
Z_TnCAP     DEFINE  0x310

; TMod==========Sets mode of timers.
; C Function prototype: int TMod(int iT, int iUp, int iHMSH);
;iT:{T_T0,T_T1,T_T2,T_T3,T_T4}
;iUp:{T_CntDown,T_CntUp}
;iHMSH:{T_BIN,T_23H,T_255H}     (T1 and T2 only)
; Description of Function: Configures timer iT.
; User interface:
;   Set iT to desired Timer, 0 to 4
;   Set iUp to 1 to count up or 0 to count down.
;   Set iHMSH to the desired counter mode:  (T1 and T2 only)
;       0 = T_HTim  -> Binary mode.
;       2 = T_23H   -> 23 hour real time mode.
;       3 = T_255H  -> 255 hour real time mode.
;   Call TMod(iT, iUp, iHMSH).
;       Timer iT is stopped and the specified modes set.
;   Returns previous TCON value in r0.
; Robustness:
;  Use TCfg() before TMod.
;  Certain features are not available for certain timers. Refer to the
;  data sheet for more information.
; Side effects: Corrupts r1, r2 and r3.

                RSEG CODE
                MODULE TMod
                PUBLIC TMod
                CODE32

TMod:   stmfd   sp!,{r4}
        mov     r3,#0xff0000            ;r3 = Z_BASE;
        orr     r3,r3,#0xff000000
        cmp     r0,#4                   ;Ensure valid timer.
        andne   r0,r0,#3
        orr     r3,r3,r0,lsl#5          ;Z_BASE |= r0<<5;
        cmp     r0,#0                   ;If T0
        addeq   r3,r3,#4                ; Z_BASE += 4.

        ldr     r4,[r3,#Z_TnCON]        ;r4 = T0CON
        bic     r4,r4,#0x100
        and     r1,r1,#1
        orr     r4,r4,r1,lsl#8          ; r4 |= iUp<<8;
        cmp     r0,#1                   ;if(iT==1
        cmpne   r0,#2                   ; || iT==2)
        biceq   r4,r4,#0x030
        andeq   r2,r2,#3
        orreq   r4,r4,r2,lsl#4          ; r4 |= iHMSH<<4;

T3Mod:  ldr     r0,[r3,#Z_TnCON]        ;Get T0CON.
        str     r4,[r3,#Z_TnCON]        ;Write to T0CON
        ldmfd   sp!,{r4}
        bx      lr

                 ENDMOD  TMod

                 END

